@@ -783,6 +783,31 @@ bge_en_icl = ModelMeta(
     adapted_from="intfloat/e5-mistral-7b-instruct",
 )
 
+bge_m3_unsupervised = ModelMeta(
+    loader=partial(  # type: ignore
+        sentence_transformers_loader,
+        model_name="BAAI/bge-m3-unsupervised",
+        revision="46f03bc86361cf88102b0b517b36c8259f2946b1",
+    ),
+    name="BAAI/bge-m3-unsupervised",
+    languages=bgem3_languages,
+    open_weights=True,
+    revision="46f03bc86361cf88102b0b517b36c8259f2946b1",
+    release_date="2024-01-30",  # January 30, 2024 - BGE-M3 release date
+    n_parameters=568_000_000,
+    memory_usage_mb=2167,
+    embed_dim=1024,
+    license="mit",
+    max_tokens=8192,
+    reference="https://huggingface.co/BAAI/bge-m3-unsupervised",
+    similarity_fn_name="cosine",
+    framework=["Sentence Transformers", "PyTorch"],
+    use_instructions=False,
+    public_training_code="https://github.com/FlagOpen/FlagEmbedding",
+    public_training_data="https://huggingface.co/datasets/cfli/bge-full-data",
+    training_datasets=bge_m3_training_data,
+)
+
 manu__bge_m3_custom_fr = ModelMeta(
     name="manu/bge-m3-custom-fr",
     revision="ed3ef88678ba83ddf4c0fab71a93cb90d89a9078",
