@@ -633,7 +633,7 @@ jina_embeddings_v3 = ModelMeta(
 jina_embeddings_v2_base_en = ModelMeta(
     loader=partial(
         SentenceTransformerWrapper,
-        model_name="jinaai/jina-embeddings-v2-base-en",
+        model="jinaai/jina-embeddings-v2-base-en",
         revision="6e85f575bc273f1fd840a658067d0157933c83f0",
         trust_remote_code=True,
     ),
@@ -692,7 +692,7 @@ jina_embeddings_v2_base_en = ModelMeta(
 jina_embeddings_v2_small_en = ModelMeta(
     loader=partial(
         SentenceTransformerWrapper,
-        model_name="jinaai/jina-embeddings-v2-small-en",
+        model="jinaai/jina-embeddings-v2-small-en",
         revision="44e7d1d6caec8c883c2d4b207588504d519788d0",
         trust_remote_code=True,
     ),
@@ -751,7 +751,7 @@ jina_embeddings_v2_small_en = ModelMeta(
 jina_embedding_b_en_v1 = ModelMeta(
     loader=partial(
         SentenceTransformerWrapper,
-        model_name="jinaai/jina-embedding-b-en-v1",
+        model="jinaai/jina-embedding-b-en-v1",
         revision="32aa658e5ceb90793454d22a57d8e3a14e699516",
     ),
     name="jinaai/jina-embedding-b-en-v1",
@@ -805,7 +805,7 @@ jina_embedding_b_en_v1 = ModelMeta(
 jina_embedding_s_en_v1 = ModelMeta(
     loader=partial(
         SentenceTransformerWrapper,
-        model_name="jinaai/jina-embedding-s-en-v1",
+        model="jinaai/jina-embedding-s-en-v1",
         revision="5ac6cd473e2324c6d5f9e558a6a9f65abb57143e",
     ),
     name="jinaai/jina-embedding-s-en-v1",
