@@ -28,4 +28,7 @@ from .pol.PolishPC import *
 from .por.Assin2RTE import *
 from .por.SickBrPC import *
 from .rus.TERRa import *
+from .vie.SprintDuplicateQuestionsPCVN import *
+from .vie.TwitterSemEval2015PCVN import *
+from .vie.TwitterURLCorpusPCVN import *
 from .zho.CMTEBPairClassification import *
