@@ -13,13 +13,20 @@ from mteb.overview import get_tasks
 _HISTORIC_DATASETS = [
     "PolEmo2.0-IN",
     "PolEmo2.0-OUT",
+    "PolEmo2.0-OUT.v2",
     "PAC",
+    "PAC.v2",
     "TNews",
+    "TNews.v2",
     "IFlyTek",
+    "IFlyTek.v2",
     "MultilingualSentiment",
+    "MultilingualSentiment.v2",
     "JDReview",
+    "JDReview.v2",
     "OnlineShopping",
     "Waimai",
+    "Waimai.v2",
     "BlurbsClusteringP2P",
     "BlurbsClusteringS2S",
     "TenKGnadClusteringP2P",
